from django.db.models.signals import post_save
from django.dispatch import receiver
from django_notifications.models import Notification
from django.conf import settings

TRACKED_MODELS = settings.TRACKED_MODELS


def create_notification(sender, instance, created, **kwargs):
    if created:
        Notification.objects.create(
            app_name_model=instance._meta.model_name,
            app_name_ident=instance._meta.app_label,
            app_id_object=instance.id,
        )


# Динамически подписываем сигнал для каждой модели в TRACKED_MODELS
for model in TRACKED_MODELS:
    post_save.connect(create_notification, sender=model)





from django.contrib import admin
from django_notifications.models import Notification
from django.contrib.admin import AdminSite


class CustomAdminMixin:
    def each_context(self, request):
        context = super().each_context(request)
        unread_notifications = Notification.objects.filter(ident=True).count() if request.user.is_authenticated else 0
        context['unread_notifications'] = unread_notifications
        return context


# Наследуемся от стандартного `AdminSite`, добавляя `Mixin`
class CustomAdminSite(CustomAdminMixin, AdminSite):
    pass


# Подменяем стандартный `admin.site`
admin.site.__class__ = CustomAdminSite
